import clr
clr.AddReference("System.Drawing")
clr.AddReference("System.Windows.Forms")

import System.Drawing
import System.Windows.Forms

from System.Drawing import *
from System.Windows.Forms import *

def onValidateUnit(step, property):
    """
        This method is called when a new unit is selected
        It allow us to have a dymamic caption
    """
    step.Properties["BoxProperties/XLength"].Caption ="X Length ["+property.Value+"]"
    step.Properties["BoxProperties/YLength"].Caption ="Y Length ["+property.Value+"]"
    step.Properties["BoxProperties/ZLength"].Caption ="Z Length ["+property.Value+"]"

    step.UserInterface.GetComponent("Properties").SetProperties(step.AllProperties)
    step.UserInterface.GetComponent("Properties").Refresh()

def isPositive(step,property):
    """
        Check validity of input values
    """
    if property.Value > 0 :
        return True
    else:
        property.StateMessage = "Input has to be positive"
        return False

def CreateGeometry(step):  
    """
        This method creates the geometry
    """
    unit = step.Properties["Unit/Unit"].Value
    PreviousStep = step.Wizard.Steps["ProjectDesign"]
    #GET PROJECT
    if PreviousStep.Properties["ProjectDesign/Project"].Value =="New Project":
        oProject = oDesktop.NewProject()
    else:
        oProject = oDesktop.SetActiveProject(PreviousStep.Properties["ProjectDesign/Project"].Value)

    #Get Design
    if PreviousStep.Properties["ProjectDesign/Design"].Value =="New HFSS Design":
        oDesign = oProject.InsertDesign("HFSS", "", "DrivenModal", "")
    else:
        oDesign = oProject.SetActiveDesign(PreviousStep.Properties["ProjectDesign/Design"].Value)

    oEditor = oDesign.SetActiveEditor("3D Modeler")
    
    oEditor.SetModelUnits(
        [
            "NAME:Units Parameter",
            "Units:="       , unit,
            "Rescale:="     , False
        ])
    

    # Reading Geometry Variables
    # ACT VARIABLES
    XLength = step.Properties["BoxProperties/XLength"].Value
    YLength = step.Properties["BoxProperties/YLength"].Value
    ZLength = step.Properties["BoxProperties/ZLength"].Value

    
    CoordinateSystem = PreviousStep.Properties["CoordinateSystem/CoordinateSystem"].Value

    
    oEditor.CreateBox(
        [
            "NAME:BoxParameters",
            "XPosition:="       , "0"+unit,
            "YPosition:="       , "0"+unit,
            "ZPosition:="       , "0"+unit,
            "XSize:="       , str(XLength)+unit,
            "YSize:="       , str(YLength)+unit,
            "ZSize:="       , str(ZLength)+unit,
        ], 
        [
            "NAME:Attributes",
            "Name:="        , "Box1",
            "Flags:="       , "",
            "Color:="       , "(255 128 0)",
            "Transparency:="    , 0,
            "PartCoordinateSystem:=", CoordinateSystem,
            "UDMId:="       , "",
            "MaterialValue:="   , "\"copper\"",
            "SolveInside:="     , True
        ])
    oEditor.FitAll()
    